@@ -182,7 +182,8 @@ gtu_sr_handle_exchange_rate (GncTreeViewSplitReg *view, gnc_numeric amount, Tran
             rate_split = gtu_sr_get_rate_from_db (reg_comm, xfer_comm);
 
         /* create the exchange-rate dialog */
-        xfer = gnc_xfer_dialog (NULL, NULL);
+
+        xfer = gnc_xfer_dialog (GTK_WIDGET (view), NULL);
 
         gnc_xfer_dialog_is_exchange_dialog (xfer, &rate_split);
 
@@ -192,7 +193,7 @@ gtu_sr_handle_exchange_rate (GncTreeViewSplitReg *view, gnc_numeric amount, Tran
 
         /* Get per book option */
         gnc_xfer_dialog_set_num (xfer, gnc_get_num_action (trans, split));
-        gnc_xfer_dialog_set_date (xfer, timespecToTime64 (xaccTransRetDatePostedTS (trans)));
+        gnc_xfer_dialog_set_date (xfer, xaccTransRetDatePosted (trans));
 
         value = amount;
         if (gnc_xfer_dialog_run_exchange_dialog (xfer, &rate_split, value, reg_acc, trans, xfer_comm, expanded))
@@ -388,6 +389,7 @@ gnc_tree_util_split_reg_template_get_transfer_entry (Split *split)
 		      "sx-account", &guid,
 		      NULL);
     account = xaccAccountLookup (guid, gnc_get_current_book ());
+    guid_free (guid);
     name = account ? gnc_get_account_name_for_register (account) : NULL;
 
     return name;
@@ -824,7 +826,7 @@ void
 gnc_tree_util_split_reg_set_value_for (GncTreeViewSplitReg *view, Transaction *trans, Split *split, gnc_numeric input, gboolean force)
 {
 //    GncTreeModelSplitReg *model;
-    GtkWidget *window;
+    GtkWindow *window;
 //    Account *anchor;
 //    Account *acct = xaccSplitGetAccount (split);
 //    gnc_commodity *currency;
@@ -845,7 +847,7 @@ gnc_tree_util_split_reg_set_value_for (GncTreeViewSplitReg *view, Transaction *t
         return;
     }
 
-    window = gnc_tree_view_split_reg_get_parent (view);
+    window = gnc_ui_get_main_window (GTK_WIDGET (view));
 
     if (gtu_sr_needs_exchange_rate (view, trans, split))
     {
