@@ -289,14 +289,14 @@ verify_term_ok (NewBillTerm *nbt)
     case GNC_TERM_TYPE_DAYS:
         if (days_due_days<days_disc_days)
         {
-              gnc_error_dialog (nbt->dialog, "%s", message);
+              gnc_error_dialog (GTK_WINDOW (nbt->dialog), "%s", message);
               result=FALSE;
         }
         break;
     case GNC_TERM_TYPE_PROXIMO:
 	if (prox_due_days<prox_disc_days)
         {
-            gnc_error_dialog (nbt->dialog, "%s", message);
+            gnc_error_dialog (GTK_WINDOW (nbt->dialog), "%s", message);
             result=FALSE;
         }
         break;
@@ -324,7 +324,7 @@ new_billterm_ok_cb (NewBillTerm *nbt)
         if (name == NULL || *name == '\0')
         {
             message = _("You must provide a name for this Billing Term.");
-            gnc_error_dialog (nbt->dialog, "%s", message);
+            gnc_error_dialog (GTK_WINDOW (nbt->dialog), "%s", message);
             return FALSE;
         }
         if (gncBillTermLookupByName (btw->book, name))
@@ -332,7 +332,7 @@ new_billterm_ok_cb (NewBillTerm *nbt)
             message = g_strdup_printf(_(
                                           "You must provide a unique name for this Billing Term. "
                                           "Your choice \"%s\" is already in use."), name);
-            gnc_error_dialog (nbt->dialog, "%s", message);
+            gnc_error_dialog (GTK_WINDOW (nbt->dialog), "%s", message);
             g_free (message);
             return FALSE;
         }
@@ -664,13 +664,13 @@ billterms_delete_term_cb (GtkButton *button, BillTermsWindow *btw)
 
     if (gncBillTermGetRefcount (btw->current_term) > 0)
     {
-        gnc_error_dialog (btw->dialog,
+        gnc_error_dialog (GTK_WINDOW (btw->dialog),
                           _("Term \"%s\" is in use. You cannot delete it."),
                           gncBillTermGetName (btw->current_term));
         return;
     }
 
-    if (gnc_verify_dialog (btw->dialog, FALSE,
+    if (gnc_verify_dialog (GTK_WINDOW (btw->dialog), FALSE,
                            _("Are you sure you want to delete \"%s\"?"),
                            gncBillTermGetName (btw->current_term)))
     {
@@ -741,7 +741,7 @@ find_handler (gpointer find_data, gpointer user_data)
 
 /* Create a billterms window */
 BillTermsWindow *
-gnc_ui_billterms_window_new (QofBook *book)
+gnc_ui_billterms_window_new (GtkWindow *parent, QofBook *book)
 {
     BillTermsWindow *btw;
     GtkBuilder *builder;
@@ -783,6 +783,8 @@ gnc_ui_billterms_window_new (QofBook *book)
     // Set the style context for this dialog so it can be easily manipulated with css
     gnc_widget_set_style_context (GTK_WIDGET(btw->dialog), "GncBillTermsDialog");
 
+    gtk_window_set_transient_for (GTK_WINDOW (btw->dialog), parent);
+
     /* Initialize the view */
     view = GTK_TREE_VIEW(btw->terms_view);
     store = gtk_list_store_new (NUM_BILL_TERM_COLS, G_TYPE_STRING, G_TYPE_POINTER);
@@ -842,13 +844,13 @@ gnc_ui_billterms_window_destroy (BillTermsWindow *btw)
 #if 0
 /* Create a new billterms by name */
 GncBillTerm *
-gnc_ui_billterms_new_from_name (QofBook *book, const char *name)
+gnc_ui_billterms_new_from_name (GtkWindow *parent, QofBook *book, const char *name)
 {
     BillTermsWindow *btw;
 
     if (!book) return NULL;
 
-    btw = gnc_ui_billterms_window_new (book);
+    btw = gnc_ui_billterms_window_new (parent, book);
     if (!btw) return NULL;
 
     return new_billterm_dialog (btw, NULL, name);
