@@ -99,10 +99,15 @@ style_dimensions_destroy (BlockDimensions *dimensions)
     if (dimensions == NULL)
         return;
 
-    g_table_destroy (dimensions->cell_dimensions);
-    dimensions->cell_dimensions = NULL;
+    dimensions->refcount--;
 
-    g_free(dimensions);
+    if (dimensions->refcount == 0)
+    {
+        g_table_destroy (dimensions->cell_dimensions);
+        dimensions->cell_dimensions = NULL;
+
+        g_free(dimensions);
+    }
 }
 
 
@@ -209,8 +214,8 @@ set_dimensions_pass_one (GnucashSheet *sheet, CellBlock *cursor,
                 cd->pixel_height = gnc_item_edit_get_margin (item_edit, top_bottom) +
                                    gnc_item_edit_get_padding_border (item_edit, top_bottom);
             }
-
-            max_height = MAX(max_height, cd->pixel_height);
+            // add 1 to cd->pixel_height to allow for a cell border
+            max_height = MAX(max_height, cd->pixel_height + 1);
 
             if (cd->pixel_width > 0)
                 continue;
@@ -644,7 +649,7 @@ destroy_style_helper (gpointer key, gpointer value, gpointer user_data)
     SheetBlockStyle *style = value;
     GnucashSheet *sheet = user_data;
 
-    gnucash_sheet_style_destroy (sheet, style);
+    gnucash_sheet_style_unref (sheet, style);
     g_free (cursor_name);
 }
 
@@ -674,10 +679,12 @@ gnucash_sheet_create_styles (GnucashSheet *sheet)
     for (node = cursors; node; node = node->next)
     {
         CellBlock *cursor = node->data;
+        SheetBlockStyle *style = gnucash_sheet_style_new (sheet, cursor);
 
+        gnucash_sheet_style_ref (sheet, style);
         g_hash_table_insert (sheet->cursor_styles,
                              g_strdup (cursor->cursor_name),
-                             gnucash_sheet_style_new (sheet, cursor));
+                             style);
     }
 }
 
@@ -798,7 +805,7 @@ gnucash_sheet_get_style_from_cursor (GnucashSheet *sheet,
  */
 
 void
-gnucash_style_ref (SheetBlockStyle *style)
+gnucash_sheet_style_ref (GnucashSheet *sheet, SheetBlockStyle *style)
 {
     g_return_if_fail (style != NULL);
 
@@ -807,14 +814,14 @@ gnucash_style_ref (SheetBlockStyle *style)
 
 
 void
-gnucash_style_unref (SheetBlockStyle *style)
+gnucash_sheet_style_unref (GnucashSheet *sheet, SheetBlockStyle *style)
 {
     g_return_if_fail (style != NULL);
 
     style->refcount--;
 
-    if (style->refcount < 0)
-        g_warning ("Unbalanced Style ref/unref");
+    if (style->refcount == 0)
+        gnucash_sheet_style_destroy (sheet, style);
 }
 
 typedef struct
